/**********************************************************************
 *
 * gsdltools.cpp -- 
 * A component of the Greenstone digital library software
 * from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * Copyright (C) 1999  The New Zealand Digital Library Project
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *********************************************************************/

#include "gsdltools.h"

bool littleEndian() {
  char s[2] = {'\xFE', '\xEF'};

  if (sizeof(unsigned short) == 2)
    return *(unsigned short*)s == 0xEFFE;
  else if (sizeof(unsigned int) == 2)
    return *(unsigned int*)s == 0xEFFE;
}

text_t dm_safe (const text_t &instring) {

  text_t outstring;
  text_t::const_iterator here = instring.begin();
  text_t::const_iterator end = instring.end();
  while (here != end) {
    if (*here == '_' || *here == '\\') outstring.push_back('\\');
    outstring.push_back(*here);
    here ++;
  }
  return outstring;
}

// gsdl_system spawns a completely separate program (i.e. the calling
// program continues and terminates normally). Arguments containing special
// characters (e.g. '&') should be quoted with ""

// on unix systems youcan get the same effext as this function by doing a
// system call and putting the spawned process in the background
// (e.g. system (funcname options &);

#if defined (__WIN32__)
#include <windows.h>
void gsdl_system (char *cmd, ostream &logout) {

  STARTUPINFO ps = {sizeof(STARTUPINFO), NULL, NULL, NULL,
                    0, 0, 0, 0, 0, 0,
                    0, 0,
                    0, 0, NULL,
                    NULL, NULL, NULL};
  PROCESS_INFORMATION pi;
  BOOL res = CreateProcess(NULL,
                           cmd,
                           NULL,
                           NULL,
                           FALSE,
                           DETACHED_PROCESS,
                           NULL,
                           NULL,
                           &ps,
                           &pi);
  if (!res) {
    logout << "Failed to start " << cmd << " process, error code " << GetLastError();
  } 

  CloseHandle(pi.hProcess);
  CloseHandle(pi.hThread);
}

#endif
